@@ -1,33 +1,43 @@
-import pathlib
+"""Test CLI entry point for for vcspull."""
+
+from __future__ import annotations
+
+import contextlib
 import shutil
 import typing as t
 
 import pytest
-
 import yaml
 
-from libvcs.sync.git import GitSync
 from vcspull.__about__ import __version__
 from vcspull.cli import cli
 from vcspull.cli.sync import EXIT_ON_ERROR_MSG, NO_REPOS_FOR_TERM_MSG
 
 if t.TYPE_CHECKING:
+    import pathlib
+
+    from libvcs.sync.git import GitSync
     from typing_extensions import TypeAlias
 
-    ExpectedOutput: TypeAlias = t.Optional[t.Union[str, t.List[str]]]
+    ExpectedOutput: TypeAlias = t.Optional[t.Union[str, list[str]]]
 
 
 class SyncCLINonExistentRepo(t.NamedTuple):
+    """Pytest fixture for vcspull syncing when repo does not exist."""
+
+    # pytest internal: used for naming test
     test_id: str
+
+    # test parameters
     sync_args: list[str]
     expected_exit_code: int
-    expected_in_out: "ExpectedOutput" = None
-    expected_not_in_out: "ExpectedOutput" = None
-    expected_in_err: "ExpectedOutput" = None
-    expected_not_in_err: "ExpectedOutput" = None
+    expected_in_out: ExpectedOutput = None
+    expected_not_in_out: ExpectedOutput = None
+    expected_in_err: ExpectedOutput = None
+    expected_not_in_err: ExpectedOutput = None
 
 
-SYNC_CLI_EXISTENT_REPO_FIXTURES = [
+SYNC_CLI_EXISTENT_REPO_FIXTURES: list[SyncCLINonExistentRepo] = [
     SyncCLINonExistentRepo(
         test_id="exists",
         sync_args=["my_git_project"],
@@ -62,6 +72,7 @@ SYNC_CLI_EXISTENT_REPO_FIXTURES = [
 def test_sync_cli_filter_non_existent(
     tmp_path: pathlib.Path,
     capsys: pytest.CaptureFixture[str],
+    caplog: pytest.LogCaptureFixture,
     monkeypatch: pytest.MonkeyPatch,
     user_path: pathlib.Path,
     config_path: pathlib.Path,
@@ -69,18 +80,19 @@ def test_sync_cli_filter_non_existent(
     test_id: str,
     sync_args: list[str],
     expected_exit_code: int,
-    expected_in_out: "ExpectedOutput",
-    expected_not_in_out: "ExpectedOutput",
-    expected_in_err: "ExpectedOutput",
-    expected_not_in_err: "ExpectedOutput",
+    expected_in_out: ExpectedOutput,
+    expected_not_in_out: ExpectedOutput,
+    expected_in_err: ExpectedOutput,
+    expected_not_in_err: ExpectedOutput,
 ) -> None:
+    """Tests vcspull syncing when repo does not exist."""
     config = {
         "~/github_projects/": {
             "my_git_project": {
-                "url": f"git+file://{git_repo.dir}",
-                "remotes": {"test_remote": f"git+file://{git_repo.dir}"},
+                "url": f"git+file://{git_repo.path}",
+                "remotes": {"test_remote": f"git+file://{git_repo.path}"},
             },
-        }
+        },
     }
     yaml_config = config_path / ".vcspull.yaml"
     yaml_config_data = yaml.dump(config, default_flow_style=False)
@@ -88,13 +100,10 @@ def test_sync_cli_filter_non_existent(
 
     monkeypatch.chdir(tmp_path)
 
-    try:
+    with contextlib.suppress(SystemExit):
         cli(["sync", *sync_args])
-    except SystemExit:
-        pass
 
-    result = capsys.readouterr()
-    output = "".join(list(result.out))
+    output = "".join(list(caplog.messages) + list(capsys.readouterr().out))
 
     if expected_in_out is not None:
         if isinstance(expected_in_out, str):
@@ -110,16 +119,21 @@ def test_sync_cli_filter_non_existent(
 
 
 class SyncFixture(t.NamedTuple):
+    """Pytest fixture for vcspull sync."""
+
+    # pytest internal: used for naming test
     test_id: str
+
+    # test params
     sync_args: list[str]
     expected_exit_code: int
-    expected_in_out: "ExpectedOutput" = None
-    expected_not_in_out: "ExpectedOutput" = None
-    expected_in_err: "ExpectedOutput" = None
-    expected_not_in_err: "ExpectedOutput" = None
+    expected_in_out: ExpectedOutput = None
+    expected_not_in_out: ExpectedOutput = None
+    expected_in_err: ExpectedOutput = None
+    expected_not_in_err: ExpectedOutput = None
 
 
-SYNC_REPO_FIXTURES = [
+SYNC_REPO_FIXTURES: list[SyncFixture] = [
     # Empty (root command)
     SyncFixture(
         test_id="empty",
@@ -200,32 +214,31 @@ def test_sync(
     test_id: str,
     sync_args: list[str],
     expected_exit_code: int,
-    expected_in_out: "ExpectedOutput",
-    expected_not_in_out: "ExpectedOutput",
-    expected_in_err: "ExpectedOutput",
-    expected_not_in_err: "ExpectedOutput",
+    expected_in_out: ExpectedOutput,
+    expected_not_in_out: ExpectedOutput,
+    expected_in_err: ExpectedOutput,
+    expected_not_in_err: ExpectedOutput,
 ) -> None:
+    """Tests for vcspull sync."""
     config = {
         "~/github_projects/": {
             "my_git_repo": {
-                "url": f"git+file://{git_repo.dir}",
-                "remotes": {"test_remote": f"git+file://{git_repo.dir}"},
+                "url": f"git+file://{git_repo.path}",
+                "remotes": {"test_remote": f"git+file://{git_repo.path}"},
             },
             "broken_repo": {
-                "url": f"git+file://{git_repo.dir}",
+                "url": f"git+file://{git_repo.path}",
                 "remotes": {"test_remote": "git+file://non-existent-remote"},
             },
-        }
+        },
     }
     yaml_config = config_path / ".vcspull.yaml"
     yaml_config_data = yaml.dump(config, default_flow_style=False)
     yaml_config.write_text(yaml_config_data, encoding="utf-8")
 
     # CLI can sync
-    try:
+    with contextlib.suppress(SystemExit):
         cli(sync_args)
-    except SystemExit:
-        pass
 
     result = capsys.readouterr()
     output = "".join(list(result.out if expected_exit_code == 0 else result.err))
@@ -244,16 +257,21 @@ def test_sync(
 
 
 class SyncBrokenFixture(t.NamedTuple):
+    """Tests for vcspull  sync when something breaks."""
+
+    # pytest internal: used for naming test
     test_id: str
+
+    # test params
     sync_args: list[str]
     expected_exit_code: int
-    expected_in_out: "ExpectedOutput" = None
-    expected_not_in_out: "ExpectedOutput" = None
-    expected_in_err: "ExpectedOutput" = None
-    expected_not_in_err: "ExpectedOutput" = None
+    expected_in_out: ExpectedOutput = None
+    expected_not_in_out: ExpectedOutput = None
+    expected_in_err: ExpectedOutput = None
+    expected_not_in_err: ExpectedOutput = None
 
 
-SYNC_BROKEN_REPO_FIXTURES = [
+SYNC_BROKEN_REPO_FIXTURES: list[SyncBrokenFixture] = [
     SyncBrokenFixture(
         test_id="normal-checkout",
         sync_args=["my_git_repo"],
@@ -332,11 +350,12 @@ def test_sync_broken(
     test_id: str,
     sync_args: list[str],
     expected_exit_code: int,
-    expected_in_out: "ExpectedOutput",
-    expected_not_in_out: "ExpectedOutput",
-    expected_in_err: "ExpectedOutput",
-    expected_not_in_err: "ExpectedOutput",
+    expected_in_out: ExpectedOutput,
+    expected_not_in_out: ExpectedOutput,
+    expected_in_err: ExpectedOutput,
+    expected_not_in_err: ExpectedOutput,
 ) -> None:
+    """Tests for syncing in vcspull when unexpected error occurs."""
     github_projects = user_path / "github_projects"
     my_git_repo = github_projects / "my_git_repo"
     if my_git_repo.is_dir():
@@ -345,13 +364,13 @@ def test_sync_broken(
     config = {
         "~/github_projects/": {
             "my_git_repo": {
-                "url": f"git+file://{git_repo.dir}",
-                "remotes": {"test_remote": f"git+file://{git_repo.dir}"},
+                "url": f"git+file://{git_repo.path}",
+                "remotes": {"test_remote": f"git+file://{git_repo.path}"},
             },
             "my_git_repo_not_found": {
                 "url": "git+file:///dev/null",
             },
-        }
+        },
     }
     yaml_config = config_path / ".vcspull.yaml"
     yaml_config_data = yaml.dump(config, default_flow_style=False)
@@ -360,10 +379,8 @@ def test_sync_broken(
     # CLI can sync
     assert isinstance(sync_args, list)
 
-    try:
+    with contextlib.suppress(SystemExit):
         cli(["sync", *sync_args])
-    except SystemExit:
-        pass
 
     result = capsys.readouterr()
     out = "".join(list(result.out))
