@@ -1,4 +1,7 @@
-"""Tests for vcspull config loading."""
+"""Tests for vcspull configuration files."""
+
+from __future__ import annotations
+
 import os
 import pathlib
 import textwrap
@@ -14,24 +17,26 @@ from .fixtures import example as fixtures
 from .helpers import EnvironmentVarGuard, load_raw, write_config
 
 
-@pytest.fixture(scope="function")
+@pytest.fixture
 def yaml_config(config_path: pathlib.Path) -> pathlib.Path:
+    """Ensure and return vcspull yaml configuration file path."""
     yaml_file = config_path / "repos1.yaml"
     yaml_file.touch()
     return yaml_file
 
 
-@pytest.fixture(scope="function")
+@pytest.fixture
 def json_config(config_path: pathlib.Path) -> pathlib.Path:
+    """Ensure and return vcspull json configuration file path."""
     json_file = config_path / "repos2.json"
     json_file.touch()
     return json_file
 
 
 def test_dict_equals_yaml() -> None:
-    # Verify that example YAML is returning expected dict format.
+    """Verify that example YAML is returning expected dict fmt."""
     config = ConfigReader._load(
-        format="yaml",
+        fmt="yaml",
         content="""\
             /home/me/myproject/study/:
               linux: git+git://git.kernel.org/linux/torvalds/linux.git
@@ -58,6 +63,7 @@ def test_dict_equals_yaml() -> None:
 
 
 def test_export_json(tmp_path: pathlib.Path) -> None:
+    """Test exporting vcspull to JSON format."""
     json_config = tmp_path / ".vcspull.json"
 
     config = ConfigReader(content=fixtures.config_dict)
@@ -71,6 +77,7 @@ def test_export_json(tmp_path: pathlib.Path) -> None:
 
 
 def test_export_yaml(tmp_path: pathlib.Path) -> None:
+    """Test exporting vcspull to YAML format."""
     yaml_config = tmp_path / ".vcspull.yaml"
 
     config = ConfigReader(content=fixtures.config_dict)
@@ -83,17 +90,20 @@ def test_export_yaml(tmp_path: pathlib.Path) -> None:
 
 
 def test_scan_config(tmp_path: pathlib.Path) -> None:
-    config_files = []
+    """Test scanning of config files."""
+    config_files: list[str] = []
 
     exists = os.path.exists
     garbage_file = tmp_path / ".vcspull.psd"
     garbage_file.write_text("wat", encoding="utf-8")
 
-    for r, d, f in os.walk(str(tmp_path)):
-        for filela in (
-            x for x in f if x.endswith((".json", "yaml")) and x.startswith(".vcspull")
-        ):
-            config_files.append(str(tmp_path / filela))
+    for _r, _d, file in os.walk(str(tmp_path)):
+        config_files += [
+            str(tmp_path / scanned_file)
+            for scanned_file in file
+            if scanned_file.endswith((".json", "yaml"))
+            and scanned_file.startswith(".vcspull")
+        ]
 
     files = 0
     if exists(str(tmp_path / ".vcspull.json")):
@@ -108,6 +118,7 @@ def test_scan_config(tmp_path: pathlib.Path) -> None:
 
 
 def test_expand_shell_command_after() -> None:
+    """Test resolution / expansion of configuration shorthands and variables."""
     # Expand shell commands from string to list.
     assert is_valid_config(fixtures.config_dict)
     config = extract_repos(fixtures.config_dict)
@@ -116,7 +127,7 @@ def test_expand_shell_command_after() -> None:
 
 
 def test_expandenv_and_homevars() -> None:
-    # Assure ~ tildes and environment template vars expand.
+    """Ensure ~ tildes and environment template vars are resolved."""
     config1 = load_raw(
         """\
                 '~/study/':
@@ -134,7 +145,7 @@ def test_expandenv_and_homevars() -> None:
                   .tmux:
                     url: git+file://{git_repo_path}
                 """,
-        format="yaml",
+        fmt="yaml",
     )
     config2 = load_raw(
         """\
@@ -154,7 +165,7 @@ def test_expandenv_and_homevars() -> None:
                   }
                 }
                 """,
-        format="json",
+        fmt="json",
     )
 
     assert is_valid_config(config1)
@@ -163,19 +174,18 @@ def test_expandenv_and_homevars() -> None:
     config1_expanded = extract_repos(config1)
     config2_expanded = extract_repos(config2)
 
-    paths = [r["dir"].parent for r in config1_expanded]
+    paths = [r["path"].parent for r in config1_expanded]
     assert expand_dir(pathlib.Path("${HOME}/github_projects/")) in paths
     assert expand_dir(pathlib.Path("~/study/")) in paths
     assert expand_dir(pathlib.Path("~")) in paths
 
-    paths = [r["dir"].parent for r in config2_expanded]
+    paths = [r["path"].parent for r in config2_expanded]
     assert expand_dir(pathlib.Path("${HOME}/github_projects/")) in paths
     assert expand_dir(pathlib.Path("~/study/")) in paths
 
 
 def test_find_config_files(tmp_path: pathlib.Path) -> None:
-    # Test find_config_files in home directory.
-
+    """Test find_config_files in home directory."""
     pull_config = tmp_path / ".vcspull.yaml"
     pull_config.touch()
     with EnvironmentVarGuard() as env:
@@ -188,16 +198,16 @@ def test_find_config_files(tmp_path: pathlib.Path) -> None:
 
 
 def test_multiple_config_files_raises_exception(tmp_path: pathlib.Path) -> None:
+    """Tests an exception is raised when multiple config files are found."""
     json_conf_file = tmp_path / ".vcspull.json"
     json_conf_file.touch()
     yaml_conf_file = tmp_path / ".vcspull.yaml"
     yaml_conf_file.touch()
-    with EnvironmentVarGuard() as env:
-        with pytest.raises(exc.MultipleConfigWarning):
-            env.set("HOME", str(tmp_path))
-            assert pathlib.Path.home() == tmp_path
+    with EnvironmentVarGuard() as env, pytest.raises(exc.MultipleConfigWarning):
+        env.set("HOME", str(tmp_path))
+        assert pathlib.Path.home() == tmp_path
 
-            config.find_home_config_files()
+        config.find_home_config_files()
 
 
 def test_in_dir(
@@ -205,6 +215,7 @@ def test_in_dir(
     yaml_config: pathlib.Path,
     json_config: pathlib.Path,
 ) -> None:
+    """Tests in_dir() returns configuration files found in directory."""
     expected = [yaml_config.stem, json_config.stem]
     result = config.in_dir(config_path)
 
@@ -212,8 +223,11 @@ def test_in_dir(
 
 
 def test_find_config_path_string(
-    config_path: pathlib.Path, yaml_config: pathlib.Path, json_config: pathlib.Path
+    config_path: pathlib.Path,
+    yaml_config: pathlib.Path,
+    json_config: pathlib.Path,
 ) -> None:
+    """Tests find_config_files() returns configuration files found in directory."""
     config_files = config.find_config_files(path=config_path)
 
     assert yaml_config in config_files
@@ -225,6 +239,7 @@ def test_find_config_path_list(
     yaml_config: pathlib.Path,
     json_config: pathlib.Path,
 ) -> None:
+    """Tests find_config_files() accepts a list of search paths."""
     config_files = config.find_config_files(path=[config_path])
 
     assert yaml_config in config_files
@@ -237,6 +252,7 @@ def test_find_config_match_string(
     json_config: pathlib.Path,
     monkeypatch: pytest.MonkeyPatch,
 ) -> None:
+    """Tests find_config_files() filters files with match param passed."""
     config_files = config.find_config_files(path=config_path, match=yaml_config.stem)
     assert yaml_config in config_files
     assert json_config not in config_files
@@ -268,6 +284,7 @@ def test_find_config_match_list(
     yaml_config: pathlib.Path,
     json_config: pathlib.Path,
 ) -> None:
+    """Tests find_config_Files() accepts multiple match params."""
     config_files = config.find_config_files(
         path=[config_path],
         match=[yaml_config.stem, json_config.stem],
@@ -276,7 +293,8 @@ def test_find_config_match_list(
     assert json_config in config_files
 
     config_files = config.find_config_files(
-        path=[config_path], match=[yaml_config.stem]
+        path=[config_path],
+        match=[yaml_config.stem],
     )
     assert yaml_config in config_files
     assert len([c for c in config_files if str(yaml_config) in str(c)]) == 1
@@ -285,50 +303,69 @@ def test_find_config_match_list(
 
 
 def test_find_config_filetype_string(
-    config_path: pathlib.Path, yaml_config: pathlib.Path, json_config: pathlib.Path
+    config_path: pathlib.Path,
+    yaml_config: pathlib.Path,
+    json_config: pathlib.Path,
 ) -> None:
+    """Tests find_config_files() filters files by filetype when param passed."""
     config_files = config.find_config_files(
-        path=[config_path], match=yaml_config.stem, filetype="yaml"
+        path=[config_path],
+        match=yaml_config.stem,
+        filetype="yaml",
     )
     assert yaml_config in config_files
     assert json_config not in config_files
 
     config_files = config.find_config_files(
-        path=[config_path], match=yaml_config.stem, filetype="json"
+        path=[config_path],
+        match=yaml_config.stem,
+        filetype="json",
     )
     assert yaml_config not in config_files
     assert json_config not in config_files
 
     config_files = config.find_config_files(
-        path=[config_path], match="repos*", filetype="json"
+        path=[config_path],
+        match="repos*",
+        filetype="json",
     )
     assert yaml_config not in config_files
     assert json_config in config_files
 
     config_files = config.find_config_files(
-        path=[config_path], match="repos*", filetype="*"
+        path=[config_path],
+        match="repos*",
+        filetype="*",
     )
     assert yaml_config in config_files
     assert json_config in config_files
 
 
 def test_find_config_filetype_list(
-    config_path: pathlib.Path, yaml_config: pathlib.Path, json_config: pathlib.Path
+    config_path: pathlib.Path,
+    yaml_config: pathlib.Path,
+    json_config: pathlib.Path,
 ) -> None:
+    """Test find_config_files() accepts a list of file types, including wildcards."""
     config_files = config.find_config_files(
-        path=[config_path], match=["repos*"], filetype=["*"]
+        path=[config_path],
+        match=["repos*"],
+        filetype=["*"],
     )
     assert yaml_config in config_files
     assert json_config in config_files
 
     config_files = config.find_config_files(
-        path=[config_path], match=["repos*"], filetype=["json", "yaml"]
+        path=[config_path],
+        match=["repos*"],
+        filetype=["json", "yaml"],
     )
     assert yaml_config in config_files
     assert json_config in config_files
 
     config_files = config.find_config_files(
-        path=[config_path], filetype=["json", "yaml"]
+        path=[config_path],
+        filetype=["json", "yaml"],
     )
     assert yaml_config in config_files
     assert json_config in config_files
@@ -340,10 +377,13 @@ def test_find_config_include_home_config_files(
     yaml_config: pathlib.Path,
     json_config: pathlib.Path,
 ) -> None:
+    """Tests find_config_files() includes vcspull user configuration files."""
     with EnvironmentVarGuard() as env:
         env.set("HOME", str(tmp_path))
         config_files = config.find_config_files(
-            path=[config_path], match="*", include_home=True
+            path=[config_path],
+            match="*",
+            include_home=True,
         )
         assert yaml_config in config_files
         assert json_config in config_files
@@ -351,7 +391,9 @@ def test_find_config_include_home_config_files(
         config_file3 = tmp_path / ".vcspull.json"
         config_file3.touch()
         results = config.find_config_files(
-            path=[config_path], match="*", include_home=True
+            path=[config_path],
+            match="*",
+            include_home=True,
         )
         expected_in = config_file3
         assert expected_in in results
@@ -360,6 +402,7 @@ def test_find_config_include_home_config_files(
 
 
 def test_merge_nested_dict(tmp_path: pathlib.Path, config_path: pathlib.Path) -> None:
+    """Tests configuration merges repositories on the same path."""
     config1 = write_config(
         config_path=config_path / "repoduplicate1.yaml",
         content=textwrap.dedent(
@@ -369,7 +412,7 @@ def test_merge_nested_dict(tmp_path: pathlib.Path, config_path: pathlib.Path) ->
     url: svn+file:///path/to/svnrepo
   subRepoSameVCS: git+file://path/to/gitrepo
   vcsOn1: svn+file:///path/to/another/svn
-            """
+            """,
         ),
     )
     config2 = write_config(
@@ -381,15 +424,16 @@ def test_merge_nested_dict(tmp_path: pathlib.Path, config_path: pathlib.Path) ->
     url: git+file:///path/to/diffrepo
   subRepoSameVCS: git+file:///path/to/gitrepo
   vcsOn2: svn+file:///path/to/another/svn
-            """
+            """,
         ),
     )
 
     # Duplicate path + name with different repo URL / remotes raises.
     config_files = config.find_config_files(
-        path=config_path, match="repoduplicate[1-2]"
+        path=config_path,
+        match="repoduplicate[1-2]",
     )
     assert config1 in config_files
     assert config2 in config_files
-    with pytest.raises(Exception):
+    with pytest.raises(exc.VCSPullException):
         config.load_configs(config_files)
