@@ -1,21 +1,32 @@
-import pathlib
+"""Tests for vcspull utilities."""
 
-import pytest
+from __future__ import annotations
+
+import typing as t
 
 from vcspull.util import get_config_dir
 
+if t.TYPE_CHECKING:
+    import pathlib
+
+    import pytest
+
 
 def test_vcspull_configdir_env_var(
-    tmp_path: pathlib.Path, monkeypatch: pytest.MonkeyPatch
+    tmp_path: pathlib.Path,
+    monkeypatch: pytest.MonkeyPatch,
 ) -> None:
+    """Test retrieving config directory with VCSPULL_CONFIGDIR set."""
     monkeypatch.setenv("VCSPULL_CONFIGDIR", str(tmp_path))
 
     assert get_config_dir() == tmp_path
 
 
 def test_vcspull_configdir_xdg_config_dir(
-    tmp_path: pathlib.Path, monkeypatch: pytest.MonkeyPatch
+    tmp_path: pathlib.Path,
+    monkeypatch: pytest.MonkeyPatch,
 ) -> None:
+    """Test retrieving config directory with XDG_CONFIG_HOME set."""
     monkeypatch.setenv("XDG_CONFIG_HOME", str(tmp_path))
     vcspull_dir = tmp_path / "vcspull"
     vcspull_dir.mkdir()
@@ -24,5 +35,6 @@ def test_vcspull_configdir_xdg_config_dir(
 
 
 def test_vcspull_configdir_no_xdg(monkeypatch: pytest.MonkeyPatch) -> None:
+    """Test retrieving config directory without XDG_CONFIG_HOME set."""
     monkeypatch.delenv("XDG_CONFIG_HOME")
     assert get_config_dir()
